"""Utility functions cribbed from the
Matlab(tm) compatibility functions in MLab.
"""
from Numeric import *

# Data analysis

def mean(m,axis=0):
	"""mean(m,axis=0) returns the mean of m along the given dimension.
	Note:  if m is an integer array, integer division will occur.
	"""
	return add.reduce(m,axis)/m.shape[axis]

# sort is done in C but is done row-wise rather than column-wise
def msort(m):
	"""msort(m) returns a sort along the first dimension of m as in MATLAB.
	"""
	return transpose(sort(transpose(m)))

def median(m):
	"""median(m) returns a mean of m along the first dimension of m.
	"""
	return msort(m)[m.shape[0]/2.0]

def std(m,axis=0):
	"""std(m,axis=0) returns the standard deviation along the given 
	dimension of m.  The result is unbiased with division by N-1.
	"""
	mu = mean(m,axis)
	return sqrt(add.reduce(pow(m-mu,2),axis))/sqrt(m.shape[axis]-1.0)




























